import type { ShowSearchType, FieldNames, BaseOptionType, DefaultOptionType } from '../vc-cascader';
import type { VueNode } from '../_util/type';
import type { ExtractPropTypes, PropType } from 'vue';
import type { SizeType } from '../config-provider';
import type { ValueType } from '../vc-cascader/Cascader';
export type { BaseOptionType, DefaultOptionType, ShowSearchType };
export declare type FieldNamesType = FieldNames;
export declare type FilledFieldNamesType = Required<FieldNamesType>;
export interface CascaderOptionType extends DefaultOptionType {
    isLeaf?: boolean;
    loading?: boolean;
    children?: CascaderOptionType[];
    [key: string]: any;
}
export declare function cascaderProps<DataNodeType extends CascaderOptionType = CascaderOptionType>(): {
    multiple: {
        type: BooleanConstructor;
        default: any;
    };
    size: PropType<SizeType>;
    bordered: {
        type: BooleanConstructor;
        default: any;
    };
    placement: {
        type: PropType<"bottomLeft" | "bottomRight" | "topLeft" | "topRight">;
    };
    suffixIcon: import("vue-types").VueTypeValidableDef<any>;
    options: PropType<DataNodeType[]>;
    'onUpdate:value': PropType<(value: ValueType) => void>;
    onFocus: {
        type: PropType<(e: FocusEvent) => void>;
    };
    onBlur: {
        type: PropType<(e: FocusEvent) => void>;
    };
    onChange: PropType<(value: ValueType, selectOptions: DefaultOptionType[] | DefaultOptionType[][]) => void>;
    onKeydown: PropType<(e: KeyboardEvent) => void>;
    onKeyup: PropType<(e: KeyboardEvent) => void>;
    onClick: PropType<(e: MouseEvent) => void>;
    onMousedown: PropType<(e: MouseEvent) => void>;
    onMouseenter: PropType<(e: MouseEvent) => void>;
    onMouseleave: PropType<(e: MouseEvent) => void>;
    prefixCls: StringConstructor;
    value: {
        type: PropType<ValueType>;
    };
    disabled: {
        type: BooleanConstructor;
        default: any;
    };
    tabindex: NumberConstructor;
    open: {
        type: BooleanConstructor;
        default: any;
    };
    id: StringConstructor;
    autofocus: BooleanConstructor;
    direction: {
        type: PropType<"ltr" | "rtl">;
    };
    animation: StringConstructor;
    defaultValue: {
        type: PropType<ValueType>;
    };
    children: PropType<VueNode[]>;
    fieldNames: PropType<FieldNames>;
    transitionName: StringConstructor;
    popupClassName: StringConstructor;
    popupStyle: {
        type: PropType<import("vue").CSSProperties>;
        default: import("vue").CSSProperties;
    };
    popupVisible: {
        type: BooleanConstructor;
        default: any;
    };
    showAction: {
        type: PropType<("focus" | "click")[]>;
    };
    popupPlacement: PropType<import("../vc-select/BaseSelect").Placement>;
    getPopupContainer: {
        type: PropType<import("../vc-select/BaseSelect").RenderDOMFunc>;
    };
    onPopupVisibleChange: PropType<(open: boolean) => void>;
    dropdownStyle: {
        type: PropType<import("vue").CSSProperties>;
        default: import("vue").CSSProperties;
    };
    dropdownClassName: StringConstructor;
    dropdownMatchSelectWidth: {
        type: PropType<number | boolean>;
        default: any;
    };
    dropdownRender: {
        type: PropType<import("../vc-select/BaseSelect").DropdownRender>;
    };
    dropdownAlign: PropType<import("../vc-trigger/interface").AlignType>;
    placeholder: import("vue-types").VueTypeValidableDef<any>;
    loading: {
        type: BooleanConstructor;
        default: any;
    };
    expandIcon: import("vue-types").VueTypeValidableDef<any>;
    allowClear: {
        type: BooleanConstructor;
        default: any;
    };
    onSearch: PropType<(value: string) => void>;
    notFoundContent: import("vue-types").VueTypeValidableDef<any>;
    inputIcon: import("vue-types").VueTypeValidableDef<any>;
    getInputElement: {
        type: PropType<() => any>;
    };
    getRawInputElement: {
        type: PropType<() => any>;
    };
    searchValue: StringConstructor;
    showSearch: {
        type: PropType<boolean | ShowSearchType<DefaultOptionType>>;
        default: boolean | ShowSearchType<DefaultOptionType>;
    };
    tagRender: {
        type: PropType<(props: import("../vc-select/BaseSelect").CustomTagProps) => any>;
    };
    optionLabelRender: {
        type: PropType<(option: Record<string, any>) => any>;
    };
    onClear: PropType<() => void>;
    choiceTransitionName: StringConstructor;
    defaultOpen: {
        type: BooleanConstructor;
        default: any;
    };
    onDropdownVisibleChange: PropType<(open: boolean) => void>;
    maxTagTextLength: NumberConstructor;
    maxTagCount: {
        type: PropType<number | "responsive">;
    };
    maxTagPlaceholder: import("vue-types").VueTypeValidableDef<any>;
    showArrow: {
        type: BooleanConstructor;
        default: any;
    };
    clearIcon: import("vue-types").VueTypeValidableDef<any>;
    removeIcon: import("vue-types").VueTypeValidableDef<any>;
    searchDropdownAutoClose: {
        type: BooleanConstructor;
        default: boolean;
    };
    onPopupScroll: PropType<(e: UIEvent) => void>;
    onInputKeyDown: PropType<(e: KeyboardEvent) => void>;
    loadData: PropType<(selectOptions: DefaultOptionType[]) => void>;
    changeOnSelect: {
        type: BooleanConstructor;
        default: any;
    };
    displayRender: PropType<(opt: {
        labels: string[];
        selectedOptions?: DefaultOptionType[];
    }) => any>;
    showCheckedStrategy: {
        type: PropType<import("../vc-cascader/Cascader").ShowCheckedStrategy>;
        default: string;
    };
    expandTrigger: PropType<"click" | "hover">;
    dropdownPrefixCls: StringConstructor;
    dropdownMenuColumnStyle: {
        type: PropType<import("vue").CSSProperties>;
        default: import("vue").CSSProperties;
    };
    loadingIcon: import("vue-types").VueTypeValidableDef<any>;
};
export declare type CascaderProps = Partial<ExtractPropTypes<ReturnType<typeof cascaderProps>>>;
export interface CascaderRef {
    focus: () => void;
    blur: () => void;
}
declare const _default: {
    new (...args: any[]): {
        $: import("vue").ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            disabled: boolean;
            open: boolean;
            multiple: boolean;
            autofocus: boolean;
            popupStyle: import("vue").CSSProperties;
            popupVisible: boolean;
            dropdownStyle: import("vue").CSSProperties;
            dropdownMatchSelectWidth: number | boolean;
            loading: boolean;
            allowClear: boolean;
            bordered: boolean;
            showSearch: boolean | ShowSearchType<DefaultOptionType>;
            defaultOpen: boolean;
            showArrow: boolean;
            searchDropdownAutoClose: boolean;
            changeOnSelect: boolean;
            showCheckedStrategy: import("../vc-cascader/Cascader").ShowCheckedStrategy;
            dropdownMenuColumnStyle: import("vue").CSSProperties;
        }> & Omit<Readonly<ExtractPropTypes<{
            multiple: {
                type: BooleanConstructor;
                default: any;
            };
            size: PropType<SizeType>;
            bordered: {
                type: BooleanConstructor;
                default: any;
            };
            placement: {
                type: PropType<"bottomLeft" | "bottomRight" | "topLeft" | "topRight">;
            };
            suffixIcon: import("vue-types").VueTypeValidableDef<any>;
            options: PropType<CascaderOptionType[]>;
            'onUpdate:value': PropType<(value: ValueType) => void>;
            onFocus: {
                type: PropType<(e: FocusEvent) => void>;
            };
            onBlur: {
                type: PropType<(e: FocusEvent) => void>;
            };
            onChange: PropType<(value: ValueType, selectOptions: DefaultOptionType[] | DefaultOptionType[][]) => void>;
            onKeydown: PropType<(e: KeyboardEvent) => void>;
            onKeyup: PropType<(e: KeyboardEvent) => void>;
            onClick: PropType<(e: MouseEvent) => void>;
            onMousedown: PropType<(e: MouseEvent) => void>;
            onMouseenter: PropType<(e: MouseEvent) => void>;
            onMouseleave: PropType<(e: MouseEvent) => void>;
            prefixCls: StringConstructor;
            value: {
                type: PropType<ValueType>;
            };
            disabled: {
                type: BooleanConstructor;
                default: any;
            };
            tabindex: NumberConstructor;
            open: {
                type: BooleanConstructor;
                default: any;
            };
            id: StringConstructor;
            autofocus: BooleanConstructor;
            direction: {
                type: PropType<"ltr" | "rtl">;
            };
            animation: StringConstructor;
            defaultValue: {
                type: PropType<ValueType>;
            };
            children: PropType<VueNode[]>;
            fieldNames: PropType<FieldNames>;
            transitionName: StringConstructor;
            popupClassName: StringConstructor;
            popupStyle: {
                type: PropType<import("vue").CSSProperties>;
                default: import("vue").CSSProperties;
            };
            popupVisible: {
                type: BooleanConstructor;
                default: any;
            };
            showAction: {
                type: PropType<("focus" | "click")[]>;
            };
            popupPlacement: PropType<import("../vc-select/BaseSelect").Placement>;
            getPopupContainer: {
                type: PropType<import("../vc-select/BaseSelect").RenderDOMFunc>;
            };
            onPopupVisibleChange: PropType<(open: boolean) => void>;
            dropdownStyle: {
                type: PropType<import("vue").CSSProperties>;
                default: import("vue").CSSProperties;
            };
            dropdownClassName: StringConstructor;
            dropdownMatchSelectWidth: {
                type: PropType<number | boolean>;
                default: any;
            };
            dropdownRender: {
                type: PropType<import("../vc-select/BaseSelect").DropdownRender>;
            };
            dropdownAlign: PropType<import("../vc-trigger/interface").AlignType>;
            placeholder: import("vue-types").VueTypeValidableDef<any>;
            loading: {
                type: BooleanConstructor;
                default: any;
            };
            expandIcon: import("vue-types").VueTypeValidableDef<any>;
            allowClear: {
                type: BooleanConstructor;
                default: any;
            };
            onSearch: PropType<(value: string) => void>;
            notFoundContent: import("vue-types").VueTypeValidableDef<any>;
            inputIcon: import("vue-types").VueTypeValidableDef<any>;
            getInputElement: {
                type: PropType<() => any>;
            };
            getRawInputElement: {
                type: PropType<() => any>;
            };
            searchValue: StringConstructor;
            showSearch: {
                type: PropType<boolean | ShowSearchType<DefaultOptionType>>;
                default: boolean | ShowSearchType<DefaultOptionType>;
            };
            tagRender: {
                type: PropType<(props: import("../vc-select/BaseSelect").CustomTagProps) => any>;
            };
            optionLabelRender: {
                type: PropType<(option: Record<string, any>) => any>;
            };
            onClear: PropType<() => void>;
            choiceTransitionName: StringConstructor;
            defaultOpen: {
                type: BooleanConstructor;
                default: any;
            };
            onDropdownVisibleChange: PropType<(open: boolean) => void>;
            maxTagTextLength: NumberConstructor;
            maxTagCount: {
                type: PropType<number | "responsive">;
            };
            maxTagPlaceholder: import("vue-types").VueTypeValidableDef<any>;
            showArrow: {
                type: BooleanConstructor;
                default: any;
            };
            clearIcon: import("vue-types").VueTypeValidableDef<any>;
            removeIcon: import("vue-types").VueTypeValidableDef<any>;
            searchDropdownAutoClose: {
                type: BooleanConstructor;
                default: boolean;
            };
            onPopupScroll: PropType<(e: UIEvent) => void>;
            onInputKeyDown: PropType<(e: KeyboardEvent) => void>;
            loadData: PropType<(selectOptions: DefaultOptionType[]) => void>;
            changeOnSelect: {
                type: BooleanConstructor;
                default: any;
            };
            displayRender: PropType<(opt: {
                labels: string[];
                selectedOptions?: DefaultOptionType[];
            }) => any>;
            showCheckedStrategy: {
                type: PropType<import("../vc-cascader/Cascader").ShowCheckedStrategy>;
                default: string;
            };
            expandTrigger: PropType<"click" | "hover">;
            dropdownPrefixCls: StringConstructor;
            dropdownMenuColumnStyle: {
                type: PropType<import("vue").CSSProperties>;
                default: import("vue").CSSProperties;
            };
            loadingIcon: import("vue-types").VueTypeValidableDef<any>;
        }>> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, "disabled" | "open" | "multiple" | "autofocus" | "popupStyle" | "popupVisible" | "dropdownStyle" | "dropdownMatchSelectWidth" | "loading" | "allowClear" | "bordered" | "showSearch" | "defaultOpen" | "showArrow" | "searchDropdownAutoClose" | "changeOnSelect" | "showCheckedStrategy" | "dropdownMenuColumnStyle">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: import("vue").Slot;
        }>;
        $root: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}>;
        $parent: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}>;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: import("vue").ComponentOptionsBase<Readonly<ExtractPropTypes<{
            multiple: {
                type: BooleanConstructor;
                default: any;
            };
            size: PropType<SizeType>;
            bordered: {
                type: BooleanConstructor;
                default: any;
            };
            placement: {
                type: PropType<"bottomLeft" | "bottomRight" | "topLeft" | "topRight">;
            };
            suffixIcon: import("vue-types").VueTypeValidableDef<any>;
            options: PropType<CascaderOptionType[]>;
            'onUpdate:value': PropType<(value: ValueType) => void>;
            onFocus: {
                type: PropType<(e: FocusEvent) => void>;
            };
            onBlur: {
                type: PropType<(e: FocusEvent) => void>;
            };
            onChange: PropType<(value: ValueType, selectOptions: DefaultOptionType[] | DefaultOptionType[][]) => void>;
            onKeydown: PropType<(e: KeyboardEvent) => void>;
            onKeyup: PropType<(e: KeyboardEvent) => void>;
            onClick: PropType<(e: MouseEvent) => void>;
            onMousedown: PropType<(e: MouseEvent) => void>;
            onMouseenter: PropType<(e: MouseEvent) => void>;
            onMouseleave: PropType<(e: MouseEvent) => void>;
            prefixCls: StringConstructor;
            value: {
                type: PropType<ValueType>;
            };
            disabled: {
                type: BooleanConstructor;
                default: any;
            };
            tabindex: NumberConstructor;
            open: {
                type: BooleanConstructor;
                default: any;
            };
            id: StringConstructor;
            autofocus: BooleanConstructor;
            direction: {
                type: PropType<"ltr" | "rtl">;
            };
            animation: StringConstructor;
            defaultValue: {
                type: PropType<ValueType>;
            };
            children: PropType<VueNode[]>;
            fieldNames: PropType<FieldNames>;
            transitionName: StringConstructor;
            popupClassName: StringConstructor;
            popupStyle: {
                type: PropType<import("vue").CSSProperties>;
                default: import("vue").CSSProperties;
            };
            popupVisible: {
                type: BooleanConstructor;
                default: any;
            };
            showAction: {
                type: PropType<("focus" | "click")[]>;
            };
            popupPlacement: PropType<import("../vc-select/BaseSelect").Placement>;
            getPopupContainer: {
                type: PropType<import("../vc-select/BaseSelect").RenderDOMFunc>;
            };
            onPopupVisibleChange: PropType<(open: boolean) => void>;
            dropdownStyle: {
                type: PropType<import("vue").CSSProperties>;
                default: import("vue").CSSProperties;
            };
            dropdownClassName: StringConstructor;
            dropdownMatchSelectWidth: {
                type: PropType<number | boolean>;
                default: any;
            };
            dropdownRender: {
                type: PropType<import("../vc-select/BaseSelect").DropdownRender>;
            };
            dropdownAlign: PropType<import("../vc-trigger/interface").AlignType>;
            placeholder: import("vue-types").VueTypeValidableDef<any>;
            loading: {
                type: BooleanConstructor;
                default: any;
            };
            expandIcon: import("vue-types").VueTypeValidableDef<any>;
            allowClear: {
                type: BooleanConstructor;
                default: any;
            };
            onSearch: PropType<(value: string) => void>;
            notFoundContent: import("vue-types").VueTypeValidableDef<any>;
            inputIcon: import("vue-types").VueTypeValidableDef<any>;
            getInputElement: {
                type: PropType<() => any>;
            };
            getRawInputElement: {
                type: PropType<() => any>;
            };
            searchValue: StringConstructor;
            showSearch: {
                type: PropType<boolean | ShowSearchType<DefaultOptionType>>;
                default: boolean | ShowSearchType<DefaultOptionType>;
            };
            tagRender: {
                type: PropType<(props: import("../vc-select/BaseSelect").CustomTagProps) => any>;
            };
            optionLabelRender: {
                type: PropType<(option: Record<string, any>) => any>;
            };
            onClear: PropType<() => void>;
            choiceTransitionName: StringConstructor;
            defaultOpen: {
                type: BooleanConstructor;
                default: any;
            };
            onDropdownVisibleChange: PropType<(open: boolean) => void>;
            maxTagTextLength: NumberConstructor;
            maxTagCount: {
                type: PropType<number | "responsive">;
            };
            maxTagPlaceholder: import("vue-types").VueTypeValidableDef<any>;
            showArrow: {
                type: BooleanConstructor;
                default: any;
            };
            clearIcon: import("vue-types").VueTypeValidableDef<any>;
            removeIcon: import("vue-types").VueTypeValidableDef<any>;
            searchDropdownAutoClose: {
                type: BooleanConstructor;
                default: boolean;
            };
            onPopupScroll: PropType<(e: UIEvent) => void>;
            onInputKeyDown: PropType<(e: KeyboardEvent) => void>;
            loadData: PropType<(selectOptions: DefaultOptionType[]) => void>;
            changeOnSelect: {
                type: BooleanConstructor;
                default: any;
            };
            displayRender: PropType<(opt: {
                labels: string[];
                selectedOptions?: DefaultOptionType[];
            }) => any>;
            showCheckedStrategy: {
                type: PropType<import("../vc-cascader/Cascader").ShowCheckedStrategy>;
                default: string;
            };
            expandTrigger: PropType<"click" | "hover">;
            dropdownPrefixCls: StringConstructor;
            dropdownMenuColumnStyle: {
                type: PropType<import("vue").CSSProperties>;
                default: import("vue").CSSProperties;
            };
            loadingIcon: import("vue-types").VueTypeValidableDef<any>;
        }>>, () => JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, {
            disabled: boolean;
            open: boolean;
            multiple: boolean;
            autofocus: boolean;
            popupStyle: import("vue").CSSProperties;
            popupVisible: boolean;
            dropdownStyle: import("vue").CSSProperties;
            dropdownMatchSelectWidth: number | boolean;
            loading: boolean;
            allowClear: boolean;
            bordered: boolean;
            showSearch: boolean | ShowSearchType<DefaultOptionType>;
            defaultOpen: boolean;
            showArrow: boolean;
            searchDropdownAutoClose: boolean;
            changeOnSelect: boolean;
            showCheckedStrategy: import("../vc-cascader/Cascader").ShowCheckedStrategy;
            dropdownMenuColumnStyle: import("vue").CSSProperties;
        }, {}, string> & {
            beforeCreate?: (() => void) | (() => void)[];
            created?: (() => void) | (() => void)[];
            beforeMount?: (() => void) | (() => void)[];
            mounted?: (() => void) | (() => void)[];
            beforeUpdate?: (() => void) | (() => void)[];
            updated?: (() => void) | (() => void)[];
            activated?: (() => void) | (() => void)[];
            deactivated?: (() => void) | (() => void)[];
            beforeDestroy?: (() => void) | (() => void)[];
            beforeUnmount?: (() => void) | (() => void)[];
            destroyed?: (() => void) | (() => void)[];
            unmounted?: (() => void) | (() => void)[];
            renderTracked?: ((e: import("vue").DebuggerEvent) => void) | ((e: import("vue").DebuggerEvent) => void)[];
            renderTriggered?: ((e: import("vue").DebuggerEvent) => void) | ((e: import("vue").DebuggerEvent) => void)[];
            errorCaptured?: ((err: unknown, instance: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}>, info: string) => boolean | void) | ((err: unknown, instance: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}>, info: string) => boolean | void)[];
        };
        $forceUpdate: () => void;
        $nextTick: typeof import("vue").nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: import("vue").WatchOptions<boolean>): import("vue").WatchStopHandle;
    } & Readonly<ExtractPropTypes<{
        multiple: {
            type: BooleanConstructor;
            default: any;
        };
        size: PropType<SizeType>;
        bordered: {
            type: BooleanConstructor;
            default: any;
        };
        placement: {
            type: PropType<"bottomLeft" | "bottomRight" | "topLeft" | "topRight">;
        };
        suffixIcon: import("vue-types").VueTypeValidableDef<any>;
        options: PropType<CascaderOptionType[]>;
        'onUpdate:value': PropType<(value: ValueType) => void>;
        onFocus: {
            type: PropType<(e: FocusEvent) => void>;
        };
        onBlur: {
            type: PropType<(e: FocusEvent) => void>;
        };
        onChange: PropType<(value: ValueType, selectOptions: DefaultOptionType[] | DefaultOptionType[][]) => void>;
        onKeydown: PropType<(e: KeyboardEvent) => void>;
        onKeyup: PropType<(e: KeyboardEvent) => void>;
        onClick: PropType<(e: MouseEvent) => void>;
        onMousedown: PropType<(e: MouseEvent) => void>;
        onMouseenter: PropType<(e: MouseEvent) => void>;
        onMouseleave: PropType<(e: MouseEvent) => void>;
        prefixCls: StringConstructor;
        value: {
            type: PropType<ValueType>;
        };
        disabled: {
            type: BooleanConstructor;
            default: any;
        };
        tabindex: NumberConstructor;
        open: {
            type: BooleanConstructor;
            default: any;
        };
        id: StringConstructor;
        autofocus: BooleanConstructor;
        direction: {
            type: PropType<"ltr" | "rtl">;
        };
        animation: StringConstructor;
        defaultValue: {
            type: PropType<ValueType>;
        };
        children: PropType<VueNode[]>;
        fieldNames: PropType<FieldNames>;
        transitionName: StringConstructor;
        popupClassName: StringConstructor;
        popupStyle: {
            type: PropType<import("vue").CSSProperties>;
            default: import("vue").CSSProperties;
        };
        popupVisible: {
            type: BooleanConstructor;
            default: any;
        };
        showAction: {
            type: PropType<("focus" | "click")[]>;
        };
        popupPlacement: PropType<import("../vc-select/BaseSelect").Placement>;
        getPopupContainer: {
            type: PropType<import("../vc-select/BaseSelect").RenderDOMFunc>;
        };
        onPopupVisibleChange: PropType<(open: boolean) => void>;
        dropdownStyle: {
            type: PropType<import("vue").CSSProperties>;
            default: import("vue").CSSProperties;
        };
        dropdownClassName: StringConstructor;
        dropdownMatchSelectWidth: {
            type: PropType<number | boolean>;
            default: any;
        };
        dropdownRender: {
            type: PropType<import("../vc-select/BaseSelect").DropdownRender>;
        };
        dropdownAlign: PropType<import("../vc-trigger/interface").AlignType>;
        placeholder: import("vue-types").VueTypeValidableDef<any>;
        loading: {
            type: BooleanConstructor;
            default: any;
        };
        expandIcon: import("vue-types").VueTypeValidableDef<any>;
        allowClear: {
            type: BooleanConstructor;
            default: any;
        };
        onSearch: PropType<(value: string) => void>;
        notFoundContent: import("vue-types").VueTypeValidableDef<any>;
        inputIcon: import("vue-types").VueTypeValidableDef<any>;
        getInputElement: {
            type: PropType<() => any>;
        };
        getRawInputElement: {
            type: PropType<() => any>;
        };
        searchValue: StringConstructor;
        showSearch: {
            type: PropType<boolean | ShowSearchType<DefaultOptionType>>;
            default: boolean | ShowSearchType<DefaultOptionType>;
        };
        tagRender: {
            type: PropType<(props: import("../vc-select/BaseSelect").CustomTagProps) => any>;
        };
        optionLabelRender: {
            type: PropType<(option: Record<string, any>) => any>;
        };
        onClear: PropType<() => void>;
        choiceTransitionName: StringConstructor;
        defaultOpen: {
            type: BooleanConstructor;
            default: any;
        };
        onDropdownVisibleChange: PropType<(open: boolean) => void>;
        maxTagTextLength: NumberConstructor;
        maxTagCount: {
            type: PropType<number | "responsive">;
        };
        maxTagPlaceholder: import("vue-types").VueTypeValidableDef<any>;
        showArrow: {
            type: BooleanConstructor;
            default: any;
        };
        clearIcon: import("vue-types").VueTypeValidableDef<any>;
        removeIcon: import("vue-types").VueTypeValidableDef<any>;
        searchDropdownAutoClose: {
            type: BooleanConstructor;
            default: boolean;
        };
        onPopupScroll: PropType<(e: UIEvent) => void>;
        onInputKeyDown: PropType<(e: KeyboardEvent) => void>;
        loadData: PropType<(selectOptions: DefaultOptionType[]) => void>;
        changeOnSelect: {
            type: BooleanConstructor;
            default: any;
        };
        displayRender: PropType<(opt: {
            labels: string[];
            selectedOptions?: DefaultOptionType[];
        }) => any>;
        showCheckedStrategy: {
            type: PropType<import("../vc-cascader/Cascader").ShowCheckedStrategy>;
            default: string;
        };
        expandTrigger: PropType<"click" | "hover">;
        dropdownPrefixCls: StringConstructor;
        dropdownMenuColumnStyle: {
            type: PropType<import("vue").CSSProperties>;
            default: import("vue").CSSProperties;
        };
        loadingIcon: import("vue-types").VueTypeValidableDef<any>;
    }>> & import("vue").ShallowUnwrapRef<() => JSX.Element> & {} & import("vue").ComponentCustomProperties & {};
    __isFragment?: never;
    __isTeleport?: never;
    __isSuspense?: never;
} & import("vue").ComponentOptionsBase<Readonly<ExtractPropTypes<{
    multiple: {
        type: BooleanConstructor;
        default: any;
    };
    size: PropType<SizeType>;
    bordered: {
        type: BooleanConstructor;
        default: any;
    };
    placement: {
        type: PropType<"bottomLeft" | "bottomRight" | "topLeft" | "topRight">;
    };
    suffixIcon: import("vue-types").VueTypeValidableDef<any>;
    options: PropType<CascaderOptionType[]>;
    'onUpdate:value': PropType<(value: ValueType) => void>;
    onFocus: {
        type: PropType<(e: FocusEvent) => void>;
    };
    onBlur: {
        type: PropType<(e: FocusEvent) => void>;
    };
    onChange: PropType<(value: ValueType, selectOptions: DefaultOptionType[] | DefaultOptionType[][]) => void>;
    onKeydown: PropType<(e: KeyboardEvent) => void>;
    onKeyup: PropType<(e: KeyboardEvent) => void>;
    onClick: PropType<(e: MouseEvent) => void>;
    onMousedown: PropType<(e: MouseEvent) => void>;
    onMouseenter: PropType<(e: MouseEvent) => void>;
    onMouseleave: PropType<(e: MouseEvent) => void>;
    prefixCls: StringConstructor;
    value: {
        type: PropType<ValueType>;
    };
    disabled: {
        type: BooleanConstructor;
        default: any;
    };
    tabindex: NumberConstructor;
    open: {
        type: BooleanConstructor;
        default: any;
    };
    id: StringConstructor;
    autofocus: BooleanConstructor;
    direction: {
        type: PropType<"ltr" | "rtl">;
    };
    animation: StringConstructor;
    defaultValue: {
        type: PropType<ValueType>;
    };
    children: PropType<VueNode[]>;
    fieldNames: PropType<FieldNames>;
    transitionName: StringConstructor;
    popupClassName: StringConstructor;
    popupStyle: {
        type: PropType<import("vue").CSSProperties>;
        default: import("vue").CSSProperties;
    };
    popupVisible: {
        type: BooleanConstructor;
        default: any;
    };
    showAction: {
        type: PropType<("focus" | "click")[]>;
    };
    popupPlacement: PropType<import("../vc-select/BaseSelect").Placement>;
    getPopupContainer: {
        type: PropType<import("../vc-select/BaseSelect").RenderDOMFunc>;
    };
    onPopupVisibleChange: PropType<(open: boolean) => void>;
    dropdownStyle: {
        type: PropType<import("vue").CSSProperties>;
        default: import("vue").CSSProperties;
    };
    dropdownClassName: StringConstructor;
    dropdownMatchSelectWidth: {
        type: PropType<number | boolean>;
        default: any;
    };
    dropdownRender: {
        type: PropType<import("../vc-select/BaseSelect").DropdownRender>;
    };
    dropdownAlign: PropType<import("../vc-trigger/interface").AlignType>;
    placeholder: import("vue-types").VueTypeValidableDef<any>;
    loading: {
        type: BooleanConstructor;
        default: any;
    };
    expandIcon: import("vue-types").VueTypeValidableDef<any>;
    allowClear: {
        type: BooleanConstructor;
        default: any;
    };
    onSearch: PropType<(value: string) => void>;
    notFoundContent: import("vue-types").VueTypeValidableDef<any>;
    inputIcon: import("vue-types").VueTypeValidableDef<any>;
    getInputElement: {
        type: PropType<() => any>;
    };
    getRawInputElement: {
        type: PropType<() => any>;
    };
    searchValue: StringConstructor;
    showSearch: {
        type: PropType<boolean | ShowSearchType<DefaultOptionType>>;
        default: boolean | ShowSearchType<DefaultOptionType>;
    };
    tagRender: {
        type: PropType<(props: import("../vc-select/BaseSelect").CustomTagProps) => any>;
    };
    optionLabelRender: {
        type: PropType<(option: Record<string, any>) => any>;
    };
    onClear: PropType<() => void>;
    choiceTransitionName: StringConstructor;
    defaultOpen: {
        type: BooleanConstructor;
        default: any;
    };
    onDropdownVisibleChange: PropType<(open: boolean) => void>;
    maxTagTextLength: NumberConstructor;
    maxTagCount: {
        type: PropType<number | "responsive">;
    };
    maxTagPlaceholder: import("vue-types").VueTypeValidableDef<any>;
    showArrow: {
        type: BooleanConstructor;
        default: any;
    };
    clearIcon: import("vue-types").VueTypeValidableDef<any>;
    removeIcon: import("vue-types").VueTypeValidableDef<any>;
    searchDropdownAutoClose: {
        type: BooleanConstructor;
        default: boolean;
    };
    onPopupScroll: PropType<(e: UIEvent) => void>;
    onInputKeyDown: PropType<(e: KeyboardEvent) => void>;
    loadData: PropType<(selectOptions: DefaultOptionType[]) => void>;
    changeOnSelect: {
        type: BooleanConstructor;
        default: any;
    };
    displayRender: PropType<(opt: {
        labels: string[];
        selectedOptions?: DefaultOptionType[];
    }) => any>;
    showCheckedStrategy: {
        type: PropType<import("../vc-cascader/Cascader").ShowCheckedStrategy>;
        default: string;
    };
    expandTrigger: PropType<"click" | "hover">;
    dropdownPrefixCls: StringConstructor;
    dropdownMenuColumnStyle: {
        type: PropType<import("vue").CSSProperties>;
        default: import("vue").CSSProperties;
    };
    loadingIcon: import("vue-types").VueTypeValidableDef<any>;
}>>, () => JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, {
    disabled: boolean;
    open: boolean;
    multiple: boolean;
    autofocus: boolean;
    popupStyle: import("vue").CSSProperties;
    popupVisible: boolean;
    dropdownStyle: import("vue").CSSProperties;
    dropdownMatchSelectWidth: number | boolean;
    loading: boolean;
    allowClear: boolean;
    bordered: boolean;
    showSearch: boolean | ShowSearchType<DefaultOptionType>;
    defaultOpen: boolean;
    showArrow: boolean;
    searchDropdownAutoClose: boolean;
    changeOnSelect: boolean;
    showCheckedStrategy: import("../vc-cascader/Cascader").ShowCheckedStrategy;
    dropdownMenuColumnStyle: import("vue").CSSProperties;
}, {}, string> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps & import("@vue/runtime-core").Plugin;
export default _default;
